@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Protocol superclass
 ##
-## Copyright (c) 2005-2011,2013-2014,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2011,2013-2014,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -62,7 +62,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2011,2013-2014,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2011,2013-2014,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -317,5 +317,23 @@ sub capabilities
  return $self->{capabilities};
 }
 
+# Handles extracting a given argument, that may be in data refhash for all operations
+# or inside a Changes object in case of update
+sub extract_argument
+{
+ my ($self, $key, $data) = @_;
+ my $arg;
+
+ if ($self->message()->operation()->[1] eq 'update')
+ {
+  $arg = $data->set($key);
+ } elsif (Net::DRI::Util::has_key($data, $key))
+ {
+  $arg = $data->{$key};
+ }
+
+ return $arg;
+}
+
 ####################################################################################################
 1;
