@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Bundling Registration Extension Mapping for EPP
 ##
-## Copyright (c) 2015-2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2015-2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -43,12 +43,12 @@ sub register_commands
 sub setup
 {
  my ($class,$po,$version)=@_;
- state $ns = { 'b-dn' => [ 'urn:ietf:params:xml:ns:b-dn-1.0','b-dn-1.0.xsd' ] };
+ state $ns = { 'b-dn' => 'urn:ietf:params:xml:ns:b-dn-1.0' };
  $po->ns($ns);
  return;
 }
 
-sub implements { return 'https://tools.ietf.org/id/draft-ietf-regext-bundling-registration-00'; }
+sub implements { return 'https://tools.ietf.org/id/draft-ietf-regext-bundling-registration-03'; }
 
 ####################################################################################################
 
@@ -105,7 +105,7 @@ __END__
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::CNNIC::Bundling - EPP Bundling Registration Extension mapping (draft-kong-eppext-bundling-registration-02) for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::CNNIC::Bundling - EPP Bundling Registration Extension mapping (draft-kong-eppext-bundling-registration-03) for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -129,7 +129,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2015-2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2015-2016,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
