@@ -1,7 +1,7 @@
 ## Domain Registry Interface, RRI Protocol (DENIC-11)
 ##
 ## Copyright (c) 2007,2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
-##           (c) 2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+##           (c) 2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -54,7 +54,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2007,2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-          (c) 2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+          (c) 2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -82,13 +82,13 @@ sub new
  foreach my $o (qw/ns status contact/) { $self->capabilities('domain_update',$o,['add','del']); }
  foreach my $o (qw/registrant auth/)   { $self->capabilities('domain_update',$o,['set']); }
 
- $self->{ns}={ _main	=> ['http://registry.denic.de/global/1.0'],
-		tr	=> ['http://registry.denic.de/transaction/1.0'],
-		contact	=> ['http://registry.denic.de/contact/1.0'],
-		domain	=> ['http://registry.denic.de/domain/1.0'],
-		dnsentry=> ['http://registry.denic.de/dnsentry/1.0'],
-                msg	=> ['http://registry.denic.de/msg/1.0'],
-		xsi	=> ['http://www.w3.org/2001/XMLSchema-instance'],
+ $self->{ns}={ rri	=> 'http://registry.denic.de/global/1.0',
+		tr	=> 'http://registry.denic.de/transaction/1.0',
+		contact	=> 'http://registry.denic.de/contact/1.0',
+		domain	=> 'http://registry.denic.de/domain/1.0',
+		dnsentry=> 'http://registry.denic.de/dnsentry/1.0',
+                msg	=> 'http://registry.denic.de/msg/1.0',
+		xsi	=> 'http://www.w3.org/2001/XMLSchema-instance',
              };
 
  $self->factories('message',sub { my $m=Net::DRI::Protocol::RRI::Message->new(@_); $m->ns($self->{ns}); $m->version($version); return $m; });
